==> PFT-v1.1.2.tar.gz: PFT-v1.1.2/README.md <==
# PFT

PFT stands for *Plain F. Text*, where the meaning of *F.* is up to
personal interpretation. Like *Fancy* or *Fantastic*.

It is yet another static website generator. This means your content is
compiled once and the result can be served by a simple HTTP server,
without need of server-side dynamic content generation.

This project provides a library which abstracts the file system access and
maintains a clean directory layout. It allows to store content in the
content directory and to handle text files with blog entries.

The library is used by the [App::PFT](https://github.com/dacav/app-pft)
project, which provides the command line tools needed for managing the blog
and compile it in web pages.

# INSTALLATION

To install this module, run the following commands:

	perl Makefile.PL
	make
	make test
	make install

# SUPPORT AND DOCUMENTATION

After installing, you can find documentation for this module with the
perldoc command.

    perldoc App::PFT

You can also look for information at:

    RT, CPAN's request tracker (report bugs here)
        http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-PFT

    AnnoCPAN, Annotated CPAN documentation
        http://annocpan.org/dist/App-PFT

    CPAN Ratings
        http://cpanratings.perl.org/d/App-PFT

    Search CPAN
        http://search.cpan.org/dist/App-PFT/


# LICENSE AND COPYRIGHT

Copyright (C) 2015 Giovanni Simoni

PFT is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your
option) any later version.

PFT is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with PFT.  If not, see <http://www.gnu.org/licenses/>.

==> PFT-v1.4.1.tar.gz: PFT-v1.4.1/README.md <==
# PFT

[![Build Status](https://travis-ci.org/dacav/PFT.svg?branch=master)](https://travis-ci.org/dacav/PFT)

PFT stands for *Plain F. Text*, where the meaning of *F.* is up to
personal interpretation. Like *Fancy* or *Fantastic*.

It is yet another static website generator. This means your content is
compiled once and the result can be served by a simple HTTP server,
without need of server-side dynamic content generation.

This project provides a library which abstracts the file system access and
maintains a clean directory layout. It allows to store content in the
content directory and to handle text files with blog entries.

The library is used by the [App::PFT](https://github.com/dacav/app-pft)
project, which provides the command line tools needed for managing the blog
and compile it in web pages.

# INSTALLATION

To install this module, run the following commands:

	perl Makefile.PL
	make
	make test
	make install

# SUPPORT AND DOCUMENTATION

After installing, you can find documentation for this module with the
perldoc command.

    perldoc App::PFT

You can also look for information at:

    RT, CPAN's request tracker (report bugs here)
        http://rt.cpan.org/NoAuth/Bugs.html?Dist=App-PFT

    AnnoCPAN, Annotated CPAN documentation
        http://annocpan.org/dist/App-PFT

    CPAN Ratings
        http://cpanratings.perl.org/d/App-PFT

    Search CPAN
        http://search.cpan.org/dist/App-PFT/


# LICENSE AND COPYRIGHT

Copyright (C) 2015 Giovanni Simoni

PFT is free software: you can redistribute it and/or modify it under the
terms of the GNU General Public License as published by the Free
Software Foundation, either version 3 of the License, or (at your
option) any later version.

PFT is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with PFT.  If not, see <http://www.gnu.org/licenses/>.
